[lvm-devel] [PATCH 04/25] Replicator: check for active replicator

Zdenek Kabelac zkabelac at redhat.com
Sun Aug 8 08:57:16 UTC 2010


Skip activation of other heads only for a active replicator.
For inactive active all heads with linear overlay mapping

Signed-off-by: Zdenek Kabelac <zkabelac at redhat.com>
---
 tools/vgchange.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/tools/vgchange.c b/tools/vgchange.c
index 960d8dd..a3a0155 100644
--- a/tools/vgchange.c
+++ b/tools/vgchange.c
@@ -104,9 +104,9 @@ static int _activate_lvs_in_vg(struct cmd_context *cmd,
 		if ((lv->status & MIRROR_IMAGE) || (lv->status & MIRROR_LOG))
 			continue;
 
-		/* Only request activation of the first replicator-dev LV */
-		/* Avoids retry with all heads in case of failure */
-		if (lv_is_replicator_dev(lv) && (lv != first_replicator_dev(lv)))
+		/* Only request activation of the first replicated LV */
+		/* Avoids retry with all heads in case of some failure */
+		if (lv_is_active_replicated(lv) && (lv != first_replicated(lv)))
 			continue;
 
 		/* Can't deactivate a pvmove LV */
-- 
1.7.2.1




More information about the lvm-devel mailing list